@@ -29,8 +29,6 @@
 
 #include "libhildonmenu.h"
 
-#include <osso-log.h>
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -106,17 +104,17 @@ static void destroy_desktop_item(gpointer data, gpointer null)
 static GdkPixbuf *add_emblem_to_icon( GdkPixbuf *icon, GdkPixbuf *emblem )
 {
 	if ( icon == NULL ) {
-		ULOG_ERR( "add_emblem_to_icon: icon is NULL." );
+		g_warning ( "add_emblem_to_icon: icon is NULL." );
 		return NULL;
 	} else if ( emblem == NULL ) {
-		ULOG_ERR( "add_emblem_to_icon: emblem is NULL." );
+		g_warning ( "add_emblem_to_icon: emblem is NULL." );
 		return NULL;
 	}
 
 	GdkPixbuf *result = gdk_pixbuf_copy( icon );
 
 	if ( result == NULL ) {
-		ULOG_ERR( "add_emblem_to_icon: failed to copy icon.");
+		g_warning( "add_emblem_to_icon: failed to copy icon.");
 		return NULL;
 	}
 
@@ -145,13 +143,13 @@ GdkPixbuf *get_icon(const char *icon_name, int icon_size)
 				GTK_ICON_LOOKUP_NO_SVG, &error);
 
 		if (error) {
-			ULOG_ERR("Error loading icon '%s': %s\n", icon_name,
+			g_warning("Error loading icon '%s': %s\n", icon_name,
 					error->message);
 			g_error_free(error);
 			error = NULL;
 		}
 	} else {
-		ULOG_ERR("Error loading icon: no icon name\n");
+		g_warning("Error loading icon: no icon name\n");
 	}
 
 	return pixbuf;
@@ -206,13 +204,13 @@ GdkPixbuf *get_icon_with_fallback(const char *icon_name,
 				GTK_ICON_LOOKUP_NO_SVG, &error);
 
 		if (error) {
-			ULOG_ERR("Error loading icon '%s': %s\n", icon_name,
+			g_warning("Error loading icon '%s': %s\n", icon_name,
 					error->message);
 			g_error_free(error);
 			error = NULL;
 		}
 	} else {
-		ULOG_ERR("Error loading icon: no icon name\n");
+		g_warning("Error loading icon: no icon name\n");
 	}
 
 	return pixbuf;
@@ -235,11 +233,11 @@ GList *get_desktop_files(gchar *directory, GList *desktop_files)
 	}
 
 	if ((dir_handle = opendir(full_path)) == NULL) {
-		ULOG_ERR("Error reading file '%s'\n", full_path );
+		g_warning("Error reading file '%s'\n", full_path );
 		return NULL;
 	}
 
-	ULOG_DEBUG( "get_desktop_files: reading dir '%s'", full_path );
+	g_debug( "get_desktop_files: reading dir '%s'", full_path );
 
 	gchar *current_path = NULL;
 
@@ -259,12 +257,12 @@ GList *get_desktop_files(gchar *directory, GList *desktop_files)
 				dir_entry->d_name, NULL);
 
 		if (stat(current_path, &buf) < 0) {
-			ULOG_ERR("%s: %s\n",
+			g_warning("%s: %s\n",
 					current_path, strerror(errno));
 
 		} else if (S_ISDIR(buf.st_mode)) {
 			/* Recurse */
-			ULOG_DEBUG( "get_desktop_files: recursing into '%s'",
+			g_debug( "get_desktop_files: recursing into '%s'",
 					current_path );
 
 			desktop_files = get_desktop_files(g_strdup(current_path),
@@ -282,7 +280,7 @@ GList *get_desktop_files(gchar *directory, GList *desktop_files)
 			if ( g_key_file_load_from_file( key_file, current_path,
 					G_KEY_FILE_NONE, &error ) == FALSE ) {
 
-				ULOG_ERR("Error reading '%s': %s\n",
+				g_warning("Error reading '%s': %s\n",
 						current_path, error->message);
 				
 				g_error_free(error);
@@ -370,7 +368,7 @@ GList *get_desktop_files(gchar *directory, GList *desktop_files)
 			item->allocated = FALSE;
 
 
-			ULOG_DEBUG( "get_desktop_files: appending .desktop = %s",
+			g_debug( "get_desktop_files: appending .desktop = %s",
 					dir_entry->d_name);
 
 			desktop_files = g_list_append(desktop_files, item);
@@ -526,7 +524,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 		doc = xmlReadFile(filename, NULL, 0);
 
 		if (doc == NULL) {
-			ULOG_ERR( "read_menu_conf: unable to read '%s'", filename );
+			g_warning( "read_menu_conf: unable to read '%s'", filename );
 			goto check_unallocated;
 		}
         	doc_created = TRUE;
@@ -536,7 +534,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 		root_element = xmlDocGetRootElement(doc);
 
 		if (root_element == NULL) {
-			ULOG_DEBUG( "read_menu_conf: failed to get root element." );
+			g_debug( "read_menu_conf: failed to get root element." );
 			xmlFreeDoc(doc);
 			goto check_unallocated;
 		}
@@ -544,7 +542,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 
 	if (xmlStrcmp(root_element->name, (const xmlChar *) "Menu") != 0) {
 		/* Not a menu */
-		ULOG_DEBUG( "read_menu_conf: not a menu.");
+		g_debug( "read_menu_conf: not a menu.");
         xmlFreeDoc(doc);
 		goto check_unallocated;
 	}
@@ -564,7 +562,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 		if (strcmp(current_element->name, "Menu") == 0) {
 			
 			/* Submenu */
-			ULOG_DEBUG( "read_menu_conf: "
+			g_debug( "read_menu_conf: "
 					"level %i: appending submenu.", level );
 
 			gtk_tree_store_append(menu_tree, &child_iterator, iterator);
@@ -582,7 +580,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 						1);
 			}
 
-			ULOG_DEBUG( "read_menu_conf: "
+			g_debug( "read_menu_conf: "
 					"level %i: Name = '%s'", level, key);
 
 			gtk_tree_store_set(menu_tree, iterator,
@@ -660,7 +658,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 						continue;
 					}
 
-					ULOG_DEBUG( "read_menu_conf: level %i: "
+					g_debug( "read_menu_conf: level %i: "
 							"appending .desktop", level );
 
 					gtk_tree_store_append(menu_tree,
@@ -729,7 +727,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 			}
 
 		} else if (strcmp(current_element->name, "Separator") == 0) {
-			ULOG_DEBUG( "read_menu_conf: level %i: "
+			g_debug( "read_menu_conf: level %i: "
 					"appending separator.", level );
 
 			GtkTreeIter child_iter;
@@ -780,7 +778,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 		if ( !extras_iter || !gtk_tree_store_iter_is_valid(
 					menu_tree, extras_iter ) ) {
 
-			ULOG_DEBUG( "Menu '%s' does not exist.",
+			g_debug( "Menu '%s' does not exist.",
 					EXTRAS_MENU_STRING );
 
 			GtkTreeIter iter;
@@ -827,7 +825,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 
 			if ( !gtk_tree_store_iter_is_valid(
 						menu_tree, extras_iter ) ) {
-				ULOG_ERR( "read_menu_conf: "
+				g_warning( "read_menu_conf: "
 						"failed to create "
 						"'%s' -menu.",
 						EXTRAS_MENU_STRING );
@@ -854,9 +852,9 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 					"",
 					-1 );
 
-			ULOG_DEBUG( "Menu '%s' created.", EXTRAS_MENU_STRING );
+			g_debug( "Menu '%s' created.", EXTRAS_MENU_STRING );
 		} else {
-			ULOG_DEBUG( "Menu '%s' exists.", EXTRAS_MENU_STRING );
+			g_debug( "Menu '%s' exists.", EXTRAS_MENU_STRING );
 		}
 
 
@@ -866,7 +864,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
 			
 			if ( item->allocated == FALSE ) {
 
-				ULOG_DEBUG( "read_menu_conf: "
+				g_debug( "read_menu_conf: "
 						"unallocated item: '%s'",
 						item->desktop_id );
 
@@ -951,7 +949,7 @@ static void read_menu_conf(const char *filename, GtkTreeStore *menu_tree,
         g_free( extras_iter );
         extras_iter = NULL;
 
-		ULOG_DEBUG( "read_menu_conf: DONE!" );
+		g_debug( "read_menu_conf: DONE!" );
 	}
 
 	return;
@@ -994,7 +992,7 @@ GtkTreeModel *get_menu_contents(void)
 	
 	/* If the user has her own menu file.. */
 	if ( g_file_test( user_menu_conf_file, G_FILE_TEST_EXISTS ) ) {
-		ULOG_DEBUG( "get_menu_contents: using user menu file = '%s'\n",
+		g_debug( "get_menu_contents: using user menu file = '%s'\n",
 				user_menu_conf_file );
 
 		/* .. read it */
@@ -1027,7 +1025,7 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 
 	/* Make sure we have a valid iterator */
 	if (!gtk_tree_store_iter_is_valid( menu_tree, iterator) ) {
-		ULOG_ERR(  "write_menu_conf: invalid iterator." );
+		g_warning(  "write_menu_conf: invalid iterator." );
 		return FALSE;
 	}
 
@@ -1045,11 +1043,11 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 			/* </Include> */
 			if ( include_open == TRUE ) {
 				if ( xmlTextWriterEndElement( writer ) < 0 ) {
-					ULOG_ERR( "write_menu_conf: "
+					g_warning( "write_menu_conf: "
 					          "failed to end Include element." );
 					goto cleanup_and_exit;
 				} else {
-					ULOG_DEBUG( "write_menu_conf: </Include>" );
+					g_debug( "write_menu_conf: </Include>" );
 				}
 				include_open = FALSE;
 			}
@@ -1057,20 +1055,20 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 			/* <Menu> */
 			if ( xmlTextWriterStartElement( writer,
 						BAD_CAST "Menu" ) < 0 ) {
-				ULOG_ERR( "write_menu_conf: "
+				g_warning( "write_menu_conf: "
 				          "failed to start Menu element." );
 				goto cleanup_and_exit;
 			} else {
-				ULOG_DEBUG( "write_menu_conf: <Menu>" );
+				g_debug( "write_menu_conf: <Menu>" );
 			}
 
 			/* <Name> ... </Name> */
 			if ( xmlTextWriterWriteElement( writer, "Name", name ) < 0 ) {
-				ULOG_ERR( "write_menu_conf: "
+				g_warning( "write_menu_conf: "
 				          "failed to write Name element." );
 				goto cleanup_and_exit;
 			} else {
-				ULOG_DEBUG( "write_menu_conf: <Name>%s</Name>", name );
+				g_debug( "write_menu_conf: <Name>%s</Name>", name );
 			}
 
 			GtkTreeIter child_iterator;
@@ -1082,18 +1080,18 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 				/* Recurse */
 				if ( !write_menu_conf( writer, menu_tree,
 							&child_iterator ) ) {
-					ULOG_ERR( "write_menu_conf: failed to recurse." );
+					g_warning( "write_menu_conf: failed to recurse." );
 					goto cleanup_and_exit;
 				}
 			}
 
 			/* </Menu> */
 			if ( xmlTextWriterEndElement( writer ) < 0 ) {
-				ULOG_ERR ( "write_menu_conf: "
+				g_warning ( "write_menu_conf: "
 				           "failed to end Menu element." );
 				goto cleanup_and_exit;
 			} else {
-				ULOG_DEBUG( "write_menu_conf: </Menu>" );
+				g_debug( "write_menu_conf: </Menu>" );
 			}
 
 		} else if ( desktop_id && strcmp( desktop_id,
@@ -1101,11 +1099,11 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 			/* </Include> */
 			if ( include_open == TRUE ) {
 				if ( xmlTextWriterEndElement( writer ) < 0 ) {
-					ULOG_ERR( "write_menu_conf: "
+					g_warning( "write_menu_conf: "
 					          "failed to end Include element." );
 					goto cleanup_and_exit;
 				} else {
-					ULOG_DEBUG( "write_menu_conf: </Include>" );
+					g_debug( "write_menu_conf: </Include>" );
 				}
 				include_open = FALSE;
 			}
@@ -1117,18 +1115,18 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 			xmlTextWriterWriteElement( writer, "Separator", NULL );
 			xmlTextWriterEndElement( writer );
 
-			ULOG_DEBUG( "write_menu_conf: <Separator/>" );
+			g_debug( "write_menu_conf: <Separator/>" );
 
 		} else if ( desktop_id && strlen ( desktop_id ) > 0 ) {
 			/* <Include> */
 			if ( include_open == FALSE ) {
 				if ( xmlTextWriterStartElement( writer,
 						BAD_CAST "Include") < 0 ) {
-					ULOG_ERR( "write_menu_conf: "
+					g_warning( "write_menu_conf: "
 					          "failed to start Include element." );
 					goto cleanup_and_exit;
 				} else {
-					ULOG_DEBUG( "write_menu_conf: <Include>" );
+					g_debug( "write_menu_conf: <Include>" );
 				}
 
 				include_open = TRUE;
@@ -1137,16 +1135,16 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 			/* <Filename> ... </Filename> */
 			if ( xmlTextWriterWriteElement( writer,
 					"Filename", desktop_id ) < 0 ) {
-				ULOG_ERR( "write_menu_conf: "
+				g_warning( "write_menu_conf: "
 				          "failed to write Filename element." );
 				goto cleanup_and_exit;
 			} else {
-				ULOG_DEBUG( "write_menu_conf: "
+				g_debug( "write_menu_conf: "
 				            "<Filename>%s</Filename>", desktop_id );
 			}
 
 		} else {
-			ULOG_ERR( "write_menu_conf: 'what happen?'"
+			g_warning( "write_menu_conf: 'what happen?'"
 			          " - 'somebody set us up the bomb!'" );
 			goto cleanup_and_exit;
 		}
@@ -1166,11 +1164,11 @@ gboolean write_menu_conf( xmlTextWriterPtr writer,
 	/* </Include> */
 	if ( include_open == TRUE ) {
 		if ( xmlTextWriterEndElement( writer ) < 0 ) {
-			ULOG_ERR( "write_menu_conf: "
+			g_warning( "write_menu_conf: "
 			          "failed to end Include element." );
 			goto cleanup_and_exit;
 		} else {
-			ULOG_DEBUG( "write_menu_conf: </Include>" );
+			g_debug( "write_menu_conf: </Include>" );
 		}
 		include_open = FALSE;
 	}
@@ -1198,7 +1196,7 @@ void find_first_and_last_root_level_folders( GtkTreeModel *model,
 	g_assert( GTK_IS_TREE_MODEL( model ) );
 
 	if ( first_folder == NULL && last_folder == NULL ) {
-		ULOG_DEBUG( "find_first_and_last_root_level_folders: "
+		g_debug( "find_first_and_last_root_level_folders: "
 				"first_folder and last_folder are both "
 				"NULL. Doing nothing." );
 		return;
@@ -1209,12 +1207,12 @@ void find_first_and_last_root_level_folders( GtkTreeModel *model,
 	GtkTreeIter last_iter;
 
 	if ( !gtk_tree_model_get_iter_first( model, &top_iter ) ) {
-		ULOG_ERR( "find_first_and_last_root_level_folders: model is empty." );
+		g_warning( "find_first_and_last_root_level_folders: model is empty." );
 		return;
 	}
 
 	if ( !gtk_tree_model_iter_children( model, &child_iter, &top_iter ) ) {
-		ULOG_ERR( "find_first_and_last_root_level_folders: tree is empty." );
+		g_warning( "find_first_and_last_root_level_folders: tree is empty." );
 		return;
 	}
 
@@ -1275,12 +1273,12 @@ gboolean set_separators( GtkTreeModel *model )
 	GtkTreeIter child_iter;
 
 	if ( !gtk_tree_model_get_iter_first( model, &top_iter ) ) {
-		ULOG_ERR( "set_separators: model is empty." );
+		g_warning( "set_separators: model is empty." );
 		return FALSE;
 	}
 
 	if ( !gtk_tree_model_iter_children( model, &child_iter, &top_iter ) ) {
-		ULOG_ERR( "set_separators: tree is empty." );
+		g_warning( "set_separators: tree is empty." );
 		return FALSE;
 	}
 
@@ -1334,17 +1332,17 @@ gboolean set_separators( GtkTreeModel *model )
 			if ( first_separator == NULL ) {
 				first_separator = gtk_tree_row_reference_new(
 						model, path );
-				ULOG_DEBUG( "set_separators: found first separator." );
+				g_debug( "set_separators: found first separator." );
 			} else if ( last_separator == NULL ) {
 				last_separator = gtk_tree_row_reference_new(
 						model, path );
-				ULOG_DEBUG( "set_separators: found last separator." );
+				g_debug( "set_separators: found last separator." );
 			} else {
-				ULOG_ERR( "set_separators: more than two separators." );
+				g_warning( "set_separators: more than two separators." );
 			}
 		} else {
 			if ( !desktop_id || strlen( desktop_id ) == 0 ) {
-				ULOG_DEBUG( "set_separators: "
+				g_debug( "set_separators: "
 						"item is a folder '%s'", name );
 
 				/* Empty Extras -folder is ignored */
@@ -1355,7 +1353,7 @@ gboolean set_separators( GtkTreeModel *model )
 						empty_extras_folder =
 							gtk_tree_row_reference_new(
 								model, path );
-						ULOG_DEBUG( "set_separators: "
+						g_debug( "set_separators: "
 						            "found empty Extras -folder." );
 						continue;
 					}
@@ -1383,7 +1381,7 @@ gboolean set_separators( GtkTreeModel *model )
 				last_folder = gtk_tree_row_reference_new(
 						model, path );
 			} else {
-				ULOG_DEBUG( "set_separators: "
+				g_debug( "set_separators: "
 						"item is an application '%s'", name );
 
 				/* It's an application */
@@ -1411,7 +1409,7 @@ gboolean set_separators( GtkTreeModel *model )
 
 	/* Add the top separator if needed */
 	if ( first_item == 2 ) {
-		ULOG_DEBUG( "set_separators: first item is a folder, no top separator." );
+		g_debug( "set_separators: first item is a folder, no top separator." );
 	} else if ( first_item == 1 ) {
 
 		/* Get the iterators */
@@ -1442,14 +1440,14 @@ gboolean set_separators( GtkTreeModel *model )
 				TREE_MODEL_DESKTOP_ID,
 				SEPARATOR_STRING, -1 );
 
-		ULOG_DEBUG( "set_separators: first item is an app, top separator added." );
+		g_debug( "set_separators: first item is an app, top separator added." );
 	} else {
-		ULOG_DEBUG( "set_separators: menu is empty?" );
+		g_debug( "set_separators: menu is empty?" );
 	}
 
 	/* Add the nottom separator if needed */
 	if ( last_item == 2 ) {
-		ULOG_DEBUG( "set_separators: last item is a folder, no bottom separator." );
+		g_debug( "set_separators: last item is a folder, no bottom separator." );
 	} else if ( last_item == 1 ) {
 		/* Get the iterators */
 		GtkTreeIter iter;
@@ -1479,9 +1477,9 @@ gboolean set_separators( GtkTreeModel *model )
 				TREE_MODEL_DESKTOP_ID,
 				SEPARATOR_STRING, -1 );
 
-		ULOG_DEBUG( "set_separators: last item is an app, bottom separator added." );
+		g_debug( "set_separators: last item is an app, bottom separator added." );
 	} else {
-		ULOG_DEBUG( "set_separators: menu is empty?" );
+		g_debug( "set_separators: menu is empty?" );
 	}
 
 	/* Remove the original separators */
@@ -1545,21 +1543,21 @@ gboolean set_menu_contents( GtkTreeModel *model )
 	buffer = xmlBufferCreate();
 	
 	if ( buffer == NULL ) {
-		ULOG_ERR( "set_menu_contents: failed to create xml buffer." );
+		g_warning( "set_menu_contents: failed to create xml buffer." );
 		return FALSE;
 	}
 
 	writer = xmlNewTextWriterMemory( buffer, 0 );
 
 	if ( writer == NULL ) {
-		ULOG_ERR( "set_menu_contents: failed to create xml writer." );
+		g_warning( "set_menu_contents: failed to create xml writer." );
 		xmlBufferFree( buffer );
 		xmlCleanupParser();
 		return FALSE;
 	}
 
 	if ( xmlTextWriterStartDocument( writer, NULL, "UTF-8", NULL ) < 0 ) {
-		ULOG_ERR( "set_menu_contents: failed to start the document." );
+		g_warning( "set_menu_contents: failed to start the document." );
 		goto cleanup_and_exit;
 
 	}
@@ -1570,18 +1568,18 @@ gboolean set_menu_contents( GtkTreeModel *model )
 
 	if ( !gtk_tree_store_iter_is_valid(
 				GTK_TREE_STORE( model ), &iterator ) ) {
-		ULOG_ERR( "set_menu_contents: failed to get iterator." );
+		g_warning( "set_menu_contents: failed to get iterator." );
 		goto cleanup_and_exit;	
 	}
 
 	if ( write_menu_conf( writer, GTK_TREE_STORE( model ), &iterator ) == FALSE ) {
-		ULOG_ERR( "set_menu_contents: failed to write menu conf." );
+		g_warning( "set_menu_contents: failed to write menu conf." );
 		goto cleanup_and_exit;
 	}
 
 	/* End the document */
 	if ( xmlTextWriterEndDocument( writer ) ) {
-		ULOG_ERR( "et_menu_contents: failed to end the document." );
+		g_warning( "et_menu_contents: failed to end the document." );
 		goto cleanup_and_exit;
 	} else {
 		xmlFreeTextWriter( writer );
@@ -1596,7 +1594,7 @@ gboolean set_menu_contents( GtkTreeModel *model )
 	user_menu_dir = g_path_get_dirname( user_menu_conf_file );
 	
 	if ( g_mkdir_with_parents( user_menu_dir, 0755  ) < 0 ) {
-		ULOG_ERR( "set_menu_contents: "
+		g_warning( "set_menu_contents: "
 				"failed to create directory '%s'.",
 				user_menu_dir );
 		goto cleanup_and_exit;
@@ -1606,11 +1604,11 @@ gboolean set_menu_contents( GtkTreeModel *model )
 	fp = fopen(user_menu_conf_file, "w");
 
 	if (fp == NULL) {
-		ULOG_ERR( "set_menu_contents: failed to open '%s' for writing.",
+		g_warning( "set_menu_contents: failed to open '%s' for writing.",
 				user_menu_conf_file );
 		goto cleanup_and_exit;
 	} else {
-		ULOG_DEBUG( "set_menu_contents: writing to '%s'.", user_menu_conf_file );
+		g_debug( "set_menu_contents: writing to '%s'.", user_menu_conf_file );
 		return_value = TRUE;
 	}
 
